Django IBAN
===========

**A validated Django model field for** `International Bank Account Numbers`_ **(IBAN).**

**Author:** Ben Konrath

**License:** 3-clause BSD

.. image:: https://secure.travis-ci.org/benkonrath/django-iban.png?branch=master
   :target: http://travis-ci.org/benkonrath/django-iban?branch=master

Pull requests happily accepted.

.. _International Bank Account Numbers: https://en.wikipedia.org/wiki/International_Bank_Account_Number
